import React from 'react'
import { Parallax } from "react-scroll-parallax";
import Slider from "react-slick";
import "slick-carousel/slick/slick.css";
import "slick-carousel/slick/slick-theme.css";
import Image from 'next/image';


const HomeMonthly = () => {
  const settings = {
    dots: false,
    infinite: true,
    slidesToShow: 3,
    slidesToScroll: 1,
    autoplay: true,
    speed: 3000,
    autoplaySpeed: 3000,
    cssEase: "linear",
    responsive: [
      {
        breakpoint: 815,
        settings: {
          slidesToShow: 2,
          slidesToScroll: 2,
          initialSlide: 2
        }
      },
      {
        breakpoint: 480,
        settings: {
          slidesToShow: 1,
          slidesToScroll: 1
        }
      }
    ]
  };
  
  return (
    <Parallax speed={0}>
      <div className='w-full h-full bg-[#5F8670] rounded-t-3xl pb-20'>
        <div className='flex flex-col gap-4 py-5 sm:py-10 px-5 lg:px-10'>
          <p className='text-center md:text-start text-3xl lg:text-[50px] leading-none xl:text-6xl 2xl:text-[5vw] text-[#BACD92] uppercase font-semibold drop-shadow-[0_3px_3px_rgba(105,105,105,1)]'>Monthly Special</p>
          <p className='w-full md:w-[500px] lg:w-[800px] text-center md:text-start text-base lg:text-lg xl:text-xl text-white'>Each month we bring different donuts to a classic flavor, so no two months are the same. Save up to 40% on special donuts only for our members!</p> 
          <p className='w-full md:w-[500px] lg:w-[800px] text-center md:text-start text-base text-white'><span className='text-red-700 text-xl'>**</span> Save up to 30% on special donuts only for our members!</p> 
        </div>
        <div className="mt-10 sm:mt-20">
          <Slider {...settings}>
            <div className='flex flex-col text-center items-center justify-center'>
              <Image src='/donut6.png' width={350} height={350} alt='monthly' className='w-[200px] sm:w-[300px] m-auto'/>
              <p className='text-white font-semibold capitalize'>Oreo cookie crumble</p>
            </div>
            <div className='flex flex-col text-center items-center justify-center'>
              <Image src='/donut7.png' width={350} height={350} alt='monthly' className='w-[250px] sm:w-[350px] m-auto'/>
              <p className='text-white font-semibold capitalize'>Reese's Peanut Butter Cup</p>
            </div>
            <div className='flex flex-col text-center items-center justify-center'>
              <Image src='/donut8.png' width={350} height={350} alt='monthly' className='w-[250px] sm:w-[350px] m-auto'/>
              <p className='text-white font-semibold capitalize'>M&M Chocolate Boston cream</p>
            </div>
            <div className='flex flex-col text-center items-center justify-center'>
              <Image src='/donut9.png' width={350} height={350} alt='monthly' className='w-[250px] sm:w-[350px] m-auto'/>
              <p className='text-white font-semibold capitalize'>White Chocolate & Nutella Bueno</p>
            </div>
            <div className='flex flex-col text-center items-center justify-center'>
              <Image src='/donut10.png' width={350} height={350} alt='monthly' className='w-[200px] sm:w-[300px] m-auto'/>
              <p className='text-white font-semibold capitalize'>White Chocolate Matcha Pistachio</p>
            </div>
          </Slider>
        </div>
      </div>
      <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1440 320" className=' drop-shadow-[0_3px_3px_rgba(105,105,105,1)] absolute -z-10 -mt-1'>
        <path fill="#5F8670" d="M0,128L8.3,138.7C16.6,149,33,171,50,154.7C66.2,139,83,85,99,90.7C115.9,96,132,160,149,181.3C165.5,203,182,181,199,186.7C215.2,192,232,224,248,234.7C264.8,245,281,235,298,208C314.5,181,331,139,348,154.7C364.1,171,381,245,397,240C413.8,235,430,149,447,122.7C463.4,96,480,128,497,165.3C513.1,203,530,245,546,234.7C562.8,224,579,160,596,149.3C612.4,139,629,181,646,213.3C662.1,245,679,267,695,250.7C711.7,235,728,181,745,133.3C761.4,85,778,43,794,42.7C811,43,828,85,844,106.7C860.7,128,877,128,894,154.7C910.3,181,927,235,943,218.7C960,203,977,117,993,106.7C1009.7,96,1026,160,1043,186.7C1059.3,213,1076,203,1092,197.3C1109,192,1126,192,1142,176C1158.6,160,1175,128,1192,128C1208.3,128,1225,160,1241,192C1257.9,224,1274,256,1291,229.3C1307.6,203,1324,117,1341,80C1357.2,43,1374,53,1390,85.3C1406.9,117,1423,171,1432,197.3L1440,224L1440,0L1431.7,0C1423.4,0,1407,0,1390,0C1373.8,0,1357,0,1341,0C1324.1,0,1308,0,1291,0C1274.5,0,1258,0,1241,0C1224.8,0,1208,0,1192,0C1175.2,0,1159,0,1142,0C1125.5,0,1109,0,1092,0C1075.9,0,1059,0,1043,0C1026.2,0,1010,0,993,0C976.6,0,960,0,943,0C926.9,0,910,0,894,0C877.2,0,861,0,844,0C827.6,0,811,0,794,0C777.9,0,761,0,745,0C728.3,0,712,0,695,0C678.6,0,662,0,646,0C629,0,612,0,596,0C579.3,0,563,0,546,0C529.7,0,513,0,497,0C480,0,463,0,447,0C430.3,0,414,0,397,0C380.7,0,364,0,348,0C331,0,314,0,298,0C281.4,0,265,0,248,0C231.7,0,215,0,199,0C182.1,0,166,0,149,0C132.4,0,116,0,99,0C82.8,0,66,0,50,0C33.1,0,17,0,8,0L0,0Z"></path>
      </svg>
    </Parallax>
  )
}

export default HomeMonthly